package se.deig.tts;

import java.io.*;
import java.util.Random;

/**
 * Utility methods for TTS implementations
 */
public class TTSUtil {
	private static final String mSuffix = "temp_";
	private static File mTempDir;
	private static Random mRandomGenerator = new Random();
	private static File mHomeDir = new File(new File(System.getProperty("user.home")), "Deig");

	public static File getHomeDir() {
		if (!mHomeDir.exists())
			mHomeDir.mkdirs();
		return mHomeDir;
	}
	
	/**
	 * Gives a temporary folder used for TTS.
	 * @return the file object to an existing folder.
	 */
	public static File getTempDir(){
		if(mTempDir == null)
			mTempDir = new File(getHomeDir(), "Temp"+File.separator+"TTS");
		if(!mTempDir.exists())
			mTempDir.mkdirs();
		return mTempDir;
	}
	
	/**
	 * Returns a temporary file reference that can be used in TTS generation.
	 * @param extension the extension to use for the file. For a text file this parameter could be "txt".
	 * @return A file reference to a non-existing file.
	 */
	public static File getTempFile(String extension){
		//The probability for non-unique file names is close to 0.
		String name = mSuffix + System.currentTimeMillis() + "_" + mRandomGenerator.nextLong() + "." + extension;
		return new File(getTempDir(), name);
	}
	
	/**
	 * Removes all temporary files in the TTS temp folder.
	 */
	public static void clearTempDir(){
		for(File f : getTempDir().listFiles()){
			if(f.getName().startsWith(mSuffix))
				f.delete();
		}
	}
}
